import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { ChannelVO, ChannelForm, ChannelQuery } from '@/api/game/channel/types';

/**
 * 查询渠道列表
 * @param query
 * @returns {*}
 */

export const listChannel = (query?: ChannelQuery): AxiosPromise<ChannelVO[]> => {
  return request({
    url: '/game/channel/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询渠道详细
 * @param id
 */
export const getChannel = (id: string | number): AxiosPromise<ChannelVO> => {
  return request({
    url: '/game/channel/' + id,
    method: 'get'
  });
};

/**
 * 新增渠道
 * @param data
 */
export const addChannel = (data: ChannelForm) => {
  return request({
    url: '/game/channel',
    method: 'post',
    data: data
  });
};

/**
 * 修改渠道
 * @param data
 */
export const updateChannel = (data: ChannelForm) => {
  return request({
    url: '/game/channel',
    method: 'put',
    data: data
  });
};

/**
 * 删除渠道
 * @param id
 */
export const delChannel = (id: string | number | Array<string | number>) => {
  return request({
    url: '/game/channel/' + id,
    method: 'delete'
  });
};
