import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { ProductProxyVO, ProductProxyForm, ProductProxyQuery } from '@/api/game/productProxy/types';

/**
 * 查询产品代理商列表
 * @param query
 * @returns {*}
 */

export const listProductProxy = (query?: ProductProxyQuery): AxiosPromise<ProductProxyVO[]> => {
  return request({
    url: '/game/productProxy/list',
    method: 'get',
    params: query
  });
};

export const allProductProxy = (query?: ProductProxyQuery): AxiosPromise<ProductProxyVO[]> => {
  return request({
    url: '/game/productProxy/all',
    method: 'get'
  });
};

/**
 * 查询产品代理商详细
 * @param id
 */
export const getProductProxy = (id: string | number): AxiosPromise<ProductProxyVO> => {
  return request({
    url: '/game/productProxy/' + id,
    method: 'get'
  });
};

/**
 * 新增产品代理商
 * @param data
 */
export const addProductProxy = (data: ProductProxyForm) => {
  return request({
    url: '/game/productProxy',
    method: 'post',
    data: data
  });
};

/**
 * 修改产品代理商
 * @param data
 */
export const updateProductProxy = (data: ProductProxyForm) => {
  return request({
    url: '/game/productProxy',
    method: 'put',
    data: data
  });
};

/**
 * 删除产品代理商
 * @param id
 */
export const delProductProxy = (id: string | number | Array<string | number>) => {
  return request({
    url: '/game/productProxy/' + id,
    method: 'delete'
  });
};
